{% if not form %}
  <a id="editcol_{{ column }}_{{ id }}" href="#" hx-get="" hx-target="this" hx-swap="outerHTML">{{ value }}</a>
{% else %}
  <form>{% csrf_token %}
    {% for field in form.visible_fields %}
      {% if field.name == column %}
        {% if field.widget_type == "select" %}
          <select name="{{ column }}" class="td-editing" title="" id="editcol_{{ column }}_{{ id }}">
            {% for widget in field.subwidgets %}
              {{ widget }}
            {% endfor %}
          </select>
        {% endif %}
      {% endif %}
    {% endfor %}
  </form>
{% endif %}