
{% block table_header %}
  {% include templates.render_header %}
{% endblock table_header %}
{% block table_body %}
  {% include templates.render_body %}
{% endblock table_body %}
{% block table_footer %}
  {% include templates.render_footer %}
{% endblock table_footer %}


